#
# spec file for package horde3-imp
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _hordedir %(%{_sbindir}/apxs2 -q datadir)/htdocs/horde/
%define _impdir %{_hordedir}/imp

Name:           horde3-imp
Version:        4.3.11
Release:        0.3.1
Summary:        Horde IMP Web-Based Mail Client
License:        GPL-2.0+
Group:          Productivity/Networking/Email/Utilities
Url:            http://www.horde.org/imp
Source0:        ftp://ftp.horde.org/pub/imp/imp-h3-%{version}.tar.gz
Source1:        http://www.gnu.org/licenses/gpl-2.0.txt
Patch0:         imp-h3-4.3.8-usr_local.patch
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       horde3 php5
BuildRequires:  apache2-devel
BuildRequires:  horde3
BuildRequires:  pcre-devel
%if 0%{?sles_version} != 10 
BuildRequires:  fdupes
%endif

%description
A set of PHP scripts that implement an IMAP-based Web mail system.
Assuming you have an account on a server that supports IMAP, you can
theoretically use an installation of IMP to check your mail from
anywhere you have Web access.

IMP does not require an IMAP server to be running on the machine you
install it on unless you are intending to have it use the current
machine for its IMAP connections. If you are connecting to a local
server for your mail, you do not need IMAP.

IMP requires a database to be running if you want to use the extended
features, such as the address book and prefs.  It currently supports
PostgreSQL, MySql, Oracle, Informix, and Sybase.



Authors:
--------
    Chuck Hagenbuch <chuck@horde.org>
    Jason "ZeroDiViDe" Orcutt <zerodiv@zerodivide.net>
    Mike Hardy <mike@itsprojects.com>
    Ivan E. Moore II <rkrusty@tdyc.com>

%prep
%setup -qn imp-h3-%{version}
%patch0

%build
pushd config/
for i in *.dist; do %__mv $i ${i%.dist}; done
popd

%install
%__mkdir_p %{buildroot}/%{_impdir}
%__cp -r ./* %{buildroot}/%{_impdir}
%__rm -rf %{buildroot}/%{_impdir}/{docs,README,COPYING}
%__cp %{SOURCE1} %{buildroot}/%{_impdir}/COPYING
# otherwise rpm will complain upon installation attempt
sed -i -e "s@/usr/bin/php@/usr/bin/php5@g" %{buildroot}%{_impdir}/scripts/upgrades/convert_vfolders.php
sed -i -e "s@/usr/bin/php@/usr/bin/php5@g" %{buildroot}%{_impdir}/scripts/bounce_spam.php

# remove and link duplicate files  
%if 0%{?sles_version} != 10 
 %fdupes %buildroot/%{_impdir}
%endif
%find_lang imp

%clean
%__rm -rf %{buildroot}

%files -f imp.lang
%defattr(-, root, root)
%doc docs README 
%dir %{_impdir}
%{_impdir}/*.php
%{_impdir}/lib
%{_impdir}/COPYING
%{_impdir}/po
%dir %{_impdir}/locale
%dir /srv/www/htdocs/horde/imp/locale/*
%dir /srv/www/htdocs/horde/imp/locale/*/LC_MESSAGES
/srv/www/htdocs/horde/imp/locale/*/*.xml
%{_impdir}/locale/.htaccess
%{_impdir}/js
%{_impdir}/scripts
%{_impdir}/templates
%{_impdir}/themes
%attr(0750, wwwrun, www) %dir %{_impdir}/config
%attr(0640, wwwrun, www) %config(noreplace) %{_impdir}/config/*
%attr(0640, wwwrun, www) %config(noreplace) %{_impdir}/config/.htaccess

%changelog
* Sat Feb 11 2012 lang@b1-systems.de
- bnc#742804 (CVE-2012-0791)
- Fixed XSS vulnerabilities (CVE-2012-0791).
- Version 4.3.11
- Warning: All things horde3 will be EOLed by April 2012
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Aug 25 2011 lang@b1-systems.de
- make it actually install in factory, not just build
* Sat Aug 13 2011 lang@b1-systems.de
- updated FSF address
- version 4.3.10
- [jan] Don't submit the action form when reloading messages with iTip
    attachments (Bug #9502).
* Sat Oct 30 2010 lang@b1-systems.de
- updated source to 4.3.9 upstream
* Wed Oct 13 2010 lang@b1-systems.de
- updated source to 4.3.8 upstream
* Mon Mar 17 2008 mhoppe@suse.de
- removed obsolete patch files imp-h3-4.1.4-usr_local.patch imp-h3-4.2-alpha-php5_exec.patch
- added new patch files imp-h3-4.2-rc3-usr_local.patch imp-h3-4.2-rc3-php5_exec.patch
* Sun Mar 16 2008 mhoppe@suse.de
- updated to version 4.2-rc3
- changed Obsoletes to imp <= 4.1.6
- removed imp-h3-4.1.4-disable-html.patch
* Mon Dec 10 2007 suse-tux@gmx.de
- removed %%%%debug_package
* Tue Dec  4 2007 suse-tux@gmx.de
- renamed package to horde-imp
- added missing requires
- updated to version 4.2-rc1
* Wed Nov  7 2007 suse-tux@gmx.de
- added Patch3 (imp-h3-4.2-alpha-php5_exec.patch) - this patch replaces
  /usr/bin/php with /usr/bin/php5
- changed version number to 4.1.99 to show that this is an alpha release
* Tue Nov  6 2007 suse-tux@gmx.de
- updated to version 4.2-alpha
- disabled Patch1 (imp-h3-4.1.4-disable-html.patch) for now. TODO: Is this
  exploit still valid?
- added updated servers.php.kolab file
* Fri Jul 27 2007 anosek@suse.cz
- updated to version 4.1.4
  * SECURITY: Fix XSS vulnerabilities in the search screen and thread view.
  * Improve displaying of PGP messages (requires Horde 3.1.4 partially).
  * Make sure we pass a read/write IMAP stream to the filters API (Bug
    [#5054]).
  * Do not allow move to trash unless trash folder is defined (Bug #5012).
  * Fix an encoding issue with the address book popup (Bug #5050).
  * Ignore All spellchecking fixes (technology@pmi-portland.org, Bug #4922).
  * Absolute restriction on the width of the contacts window select elements
    (Request #1985).
  * Send lowercase mailto: attributes in iCalendar replies (Bug #4872).
  * Don't improperly increment iCalendar SEQUENCE values (Bug #4863).
  * Always subscribe to created folders.
  * Don't allow both trash folder and Virtual Trash to be selected in the
    options (Bug #4698).
  * Turn mailto: links in HTML emails into IMP compose links (Bug #3079).
  * Attempt to calculate the actual filesystem block size in the
    IMP_Quota_command driver (Eric Rostetter
    <eric.rostetter@physics.utexas.edu>, Request #4360).
  * Make sure to honor user date format preferences in iTip viewer
    (Bug #4635).
  * Fix message list header underflow in IE7 (Bug #4608).
  * Don't return empty sent-mail folders from the identity (Bug #4380).
  * Don't rename folders from or to an empty string (Bug #4380).
  * Don't replace spaces with '.' when expanding addresses. (Bug #4236)
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Tue Sep 12 2006 mmarek@suse.cz
- added horde directory to filelist
* Thu Aug 24 2006 suse-tux@gmx.de
- new upstream version (4.1.3)
- added imp-h3-4.1.3-usr_local.patch
* Mon Aug  7 2006 mmarek@suse.cz
- updated to version 4.1.2
  * changes from 4.0.x:
  - virtual Inbox and Virtual Trash folder
  - "Empty Spam" menu item
  - stationery and form responses
  - not necessary to click on "Attach" button when attaching files
  - play sound on new mail
  - multiple message view
  - ability to create notes from email messages
  - improved message previews
  - import of photo attachments into a gallery application
  - send notification when linked attachments are downloaded
  - graphical representation of thread on thread view screen
  - encrypt PGP messages for all recipients in one message
  - always send new messages in "flowed" format
  - auto-detection of namespace information from IMAP server
  - permission to restrict folder creation
  - support for changing SMTP server/port on login
  - more flexible custom email headers
  * changes from 4.1.0:
  - display quota for current folder on Cyrus servers
  - added preference for default charset when reading messages
  - added preference to define how to expand the folder list in sidebar
  * bugfixes and translation updates
* Fri Jun 16 2006 suse-tux@gmx.de
- added servers.php.kolab - a servers.php config file for kolab
- removed #usedforbuild and BuildRequires: libarp-util1-devel horde (horde isn't needed during the build)
- changed Requires: horde to Requires: horde >= 3.1.1
- corrected URL-tag
- added rpmmacros (changed "cp" to "%%%%__cp" etc.)
* Fri May 12 2006 lrupp@suse.de
- reduce BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 mmarek@suse.cz
- disable HTML e-mail
  [#137381] (disable-html.patch)
- make imp/config/ writable by wwwrun to allow administration via
  web form
* Tue Jan  3 2006 mmarek@suse.cz
- update to 4.0.4
- check for working apxs2 in %%%%build
- use %%config(noreplace)
* Wed May 11 2005 mcihar@suse.cz
- update to 4.0.3
* Tue Feb  8 2005 mcihar@suse.cz
- update to 4.0.1
* Tue Aug 10 2004 tcrhak@suse.cz
- update to 3.2.5
* Wed Apr 28 2004 ro@suse.de
- use apache2 to build
* Fri Feb 27 2004 hmacht@suse.de
- building as nonroot-user
* Wed Feb 25 2004 tcrhak@suse.cz
- update to version 3.2.3
- removed po files from filelist
* Mon Jun 23 2003 ro@suse.de
- added directory to filelist
- don't remove files from package in preun
* Wed Jan 22 2003 tcrhak@suse.cz
- update to version 3.1
* Thu Aug  1 2002 ro@suse.de
- adapt server-root
* Tue Sep 25 2001 adostal@suse.cz
- fix README.SuSE
- fix uninstall in %%preun section
* Fri Aug 31 2001 adostal@suse.cz
- create a new stand-alone package (v. 2.2.6)- old versions are
  generated from imapweb package
- create README.SuSE
